@@ -41,7 +41,7 @@ class Parcela(models.Model):
 class FormaPagamento(models.Model):
     """Forma de pagamento."""
 
-    CODIGOS_GATEWAYS = ['pagseguro', 'pagamento_digital', 'mercado_pago', 'paypal']
+    CODIGOS_GATEWAYS = ['pagseguro', 'pagamento_digital', 'mercadopago', 'paypal', 'mercado_pago']
 
     PRINCIPAIS_FORMAS_PAGAMENTO = {
         'pagamento_digital': {
@@ -57,6 +57,10 @@ class FormaPagamento(models.Model):
         'paypal': {
             'cartoes': ['visa', 'mastercard', 'amex']
         },
+        'mercadopago': {
+            'cartoes': ['visa', 'mastercard', 'amex', 'elo'],
+            'outros': ['boleto']
+        },
         'mercado_pago': {
             'cartoes': ['visa', 'mastercard', 'amex', 'elo'],
             'outros': ['boleto']
@@ -76,6 +80,7 @@ class FormaPagamento(models.Model):
     contrato = models.ForeignKey("plataforma.Contrato", related_name="formas_pagamentos", null=True, default=None)
 
     class Meta:
+        app_label = 'configuracao'
         db_table = u"configuracao\".\"tb_pagamento"
         verbose_name = u"Forma de pagamento"
         verbose_name_plural = u"Formas de pagamentos"
