@@ -15,6 +15,7 @@ class Contrato(models.Model):
     tipo = models.CharField(db_column="contrato_tipo", max_length=32)
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_contrato"
 
 
@@ -23,12 +24,12 @@ class Conta(models.Model):
     id = models.AutoField(db_column="conta_id", primary_key=True)
     apelido = models.CharField(db_column="conta_apelido", max_length=32)
     dominio = models.CharField(db_column="conta_loja_dominio", max_length=128, null=True, default=None)
-    situacao = models.CharField(db_column="conta_situacao")
 
     contrato = models.ForeignKey('Contrato', db_column="contrato_id")
     plano = models.ForeignKey('faturamento.Plano', db_column="plano_id")
 
     class Meta:
+        app_label = 'plataforma'
         db_table = u"plataforma\".\"tb_conta"
 
 
